@@ -7,6 +7,7 @@
 
 #include <QTest>
 
+#include <QPluginLoader>
 #include <kpluginfactory.h>
 #include <kpluginloader.h>
 
@@ -34,6 +35,7 @@ private Q_SLOTS:
         delete obj;
         delete obj2;
 
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 89)
         obj = factory->create<QObject>(QStringLiteral("secondary"), this, args);
         QVERIFY(obj);
         QCOMPARE(obj->objectName(), QString::fromLatin1("MultiPlugin2"));
@@ -44,8 +46,18 @@ private Q_SLOTS:
         QVERIFY(obj != obj2);
         delete obj;
         delete obj2;
+#endif
     }
 
+    void testResultingCMakeMacroPlugin()
+    {
+        KPluginMetaData data(QStringLiteral("plugins/namespace/jsonplugin_cmake_macro"));
+        QVERIFY(data.isValid());
+
+        auto instance = QPluginLoader(data.fileName()).instance();
+        QVERIFY(instance);
+        QCOMPARE(instance->metaObject()->className(), "jsonplugin_cmake_macro_factory");
+    }
     void testCreateUsingUtilityMethods()
     {
         auto result = KPluginFactory::instantiatePlugin<QObject>(KPluginMetaData(QStringLiteral("jsonplugin")), nullptr, QVariantList());
@@ -77,6 +89,14 @@ private Q_SLOTS:
             QCOMPARE(result.errorReason, KPluginFactory::INVALID_KPLUGINFACTORY_INSTANTIATION);
         }
     }
+
+    void testStaticPlugins()
+    {
+        const auto plugins = KPluginMetaData::findPlugins(QStringLiteral("staticnamespace"));
+        QCOMPARE(plugins.count(), 1);
+
+        QVERIFY(KPluginFactory::instantiatePlugin<QObject>(plugins.first()));
+    }
 };
 
 QTEST_MAIN(KPluginFactoryTest)
