@@ -9,6 +9,7 @@
 
 #include "kpluginmetadata.h"
 #include "desktopfileparser_p.h"
+#include "kstaticpluginhelpers_p.h"
 
 #include "kcoreaddons_debug.h"
 #include "kjsonutils.h"
@@ -26,10 +27,13 @@
 #include "kpluginfactory.h"
 #include "kpluginloader.h"
 
+#include <optional>
+
 class KPluginMetaDataPrivate : public QSharedData
 {
 public:
     QString metaDataFileName;
+    std::optional<QStaticPlugin> staticPlugin = std::nullopt;
     static void forEachPlugin(const QString &directory, std::function<void(const QString &)> callback)
     {
         QStringList dirsToCheck;
@@ -157,6 +161,18 @@ KPluginMetaData::KPluginMetaData(const QJsonObject &metaData, const QString &plu
     }
 }
 
+KPluginMetaData::KPluginMetaData(QStaticPlugin plugin, const QJsonObject &metaData)
+{
+    d = new KPluginMetaDataPrivate();
+    d->staticPlugin = plugin;
+    auto metaDataObject = plugin.metaData().value(QLatin1String("MetaData")).toObject();
+    m_metaData = metaDataObject.isEmpty() ? metaData : metaDataObject;
+    auto names = plugin.metaData().value(QLatin1String("X-KDE-FileName")).toVariant().toStringList();
+    if (!names.isEmpty()) {
+        m_fileName = names.constFirst();
+    }
+}
+
 KPluginMetaData KPluginMetaData::findPluginById(const QString &directory, const QString &pluginId)
 
 {
@@ -234,6 +250,13 @@ QString KPluginMetaData::metaDataFileName() const
 QVector<KPluginMetaData> KPluginMetaData::findPlugins(const QString &directory, std::function<bool(const KPluginMetaData &)> filter)
 {
     QVector<KPluginMetaData> ret;
+    const auto staticPlugins = KStaticPluginHelpers::staticPlugins(directory);
+    for (QStaticPlugin p : staticPlugins) {
+        KPluginMetaData metaData(p);
+        if (!filter || filter(metaData)) {
+            ret << metaData;
+        }
+    }
     QSet<QString> addedPluginIds;
     KPluginMetaDataPrivate::forEachPlugin(directory, [&](const QString &pluginPath) {
         KPluginMetaData metadata(pluginPath);
@@ -420,10 +443,12 @@ QStringList KPluginMetaData::dependencies() const
 }
 #endif
 
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 89)
 QStringList KPluginMetaData::serviceTypes() const
 {
     return rootObject().value(QStringLiteral("ServiceTypes")).toVariant().toStringList();
 }
+#endif
 
 QStringList KPluginMetaData::mimeTypes() const
 {
@@ -592,3 +617,14 @@ QVariantList KPluginMetaData::otherContributorsVariant() const
 {
     return listToVariant(otherContributors());
 }
+bool KPluginMetaData::isStaticPlugin() const
+{
+    return d && d->staticPlugin.has_value();
+}
+
+QStaticPlugin KPluginMetaData::staticPlugin() const
+{
+    Q_ASSERT(d);
+    Q_ASSERT(d->staticPlugin.has_value());
+    return d->staticPlugin.value();
+}
